import React from "react";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";

import Link from "@material-ui/core/Link";
import IconButton from "@material-ui/core/IconButton";

import ListItem from "@material-ui/core/ListItem";
import ListItemIcon from "@material-ui/core/ListItemIcon";
import ListItemText from "@material-ui/core/ListItemText";

import MenuIcon from "@material-ui/icons/Menu";
import Notifications from "@material-ui/icons/Notifications";
import NotificationsActive from "@material-ui/icons/NotificationsActive";
import BasicIcon from "@material-ui/core/Icon";

import Tooltip from "@material-ui/core/Tooltip";

const classes = {
  menuButton: "menu-button",
  menuIcon: "menu-icon",
  logoIcon: "trx-logo-icon",
  logoButton: "trx-logo-button"
};

const styles = {
  userMenu: {
    marginLeft: "auto",
    display: "flex"
  },
  bell: {
    marginLeft: "auto",
    backgroundColor: "#00ccf5",
    flex: 1,
    marginTop: "10%",
    marginLeft: "24px"
  },
  userInfo: {
    flex: 1,
    minWidth: "80px",
    maxHeight: "64px!important",
    marginRight: "17px"
  }
};

const TRXLogo = () => {
  return (
    <div>
      <img id="trx-logo-img" height="64px" src="/static/images/logo.png" />
    </div>
  );
};

const BellIcon = () => {
  return <NotificationsActive className="bell" />;
};

const EmptyBellIcon = () => {
  return <Notifications className="bell" />;
};

const menuItems = [
  {
    url: "/",
    label: "Trade",
    icon: "tradeicon"
  },
  {
    url: "/user",
    label: "Account settings",
    icon: "person"
  },
  {
    url: "/user/all",
    label: "Users: All",
    icon: ""
  },
  {
    url: "/login",
    label: "Login",
    icon: ""
  },
  {
    url: "/register",
    label: "Register",
    icon: ""
  },
  {
    url: "/heartbeat/feed",
    label: "Social Feed",
    icon: ""
  },
  {
    url: "/transaction/tx-gui",
    label: "Transaction GUI",
    icon: ""
  },
  {
    url: "/regtest/all-users",
    label: "Transaction GUI - All users",
    icon: ""
  },
  {
    url: "/admin/bot",
    label: "Bot Interface",
    icon: ""
  },
  {
    url: "/prices/graph",
    label: "BTC Price Graph",
    icon: "trending_up"
  }
];

const userMenuItems = [
  { label: "Account settings", url: "/user" },
  { label: "Logout", url: "/logout" }
];
/**
 *
 * @param {Array} menuItems An Array of menu item objects
 * @param {String} menuItems.url The URL for the menu item
 * @param {String} menuItems.label The Label for the menu item
 * @param {String} menuItems.icon The Icon for the menu item
 *
 */
const buildSideMenuItems = menuItems => {
  const children = [];
  for (let i = 0; i < menuItems.length; i++) {
    const item = menuItems[i];
    children.push(
      <ListItem button key={i}>
        <ListItemIcon>{item.icon}</ListItemIcon>
        <ListItemText primary={item.label} />
        <Link href={item.url} />
      </ListItem>
    );
  }
};

export default class TrxNav extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      open: false,
      userMenuOpen: false,
      notification: false,
      notificationMenuOpen: false,
      messages: [],
      userData: props.user || {},
      notificationAnchor: undefined
    };
  }

  componentWillReceiveProps(props) {
    if (props.drawerHandler) {
      this.drawerHandler = props.drawerHandler;
    }
    if (props.messages) {
      this.setState({ messages: { ...this.state.messages, ...props.message } });
    }
    if (props.user) {
      this.setState({ userData: props.user });
    }
    if (props.notificationMessage) {
      this.setState({
        messages: [...this.state.messages, props.notificationMessage],
        notification: true
      });
    }
  }

  handleUserMenuClick = () => {
    this.setState({ userMenuOpen: !this.state.userMenuOpen });
  };

  handleUserMenuClose = () => {
    this.setState({ userMenuOpen: false });
  };

  handleNotificationMenuClick = e => {
    this.setState({
      notificationAnchor: e.currentTarget,
      notificationMenuOpen: !this.state.notificationMenuOpen
    });
  };

  handleNotificationMenuClose = () => {
    this.setState({ notificationMenuOpen: false });
  };

  handleAllNotificationsRead = () => {
    this.setState({ notification: false });
  };

  render() {
    return (
      <div>
        <AppBar position="sticky" className="appbar" position="static">
          <Toolbar
            disableGutters={!this.state.open}
            className="toolbar"
            title="JRE"
          >
            <Tooltip title="Click to open the navigation drawer">
              <IconButton
                className={classes.menuBotton}
                onClick={this.props.drawerHandler}
              >
                <MenuIcon className={classes.menuIcon} />
              </IconButton>
            </Tooltip>
          </Toolbar>
        </AppBar>
      </div>
    );
  }
}

const logoIcon = () => {
  return (
    <BasicIcon className={classes.logoIcon} hidden={false}>
      <TRXLogo />
    </BasicIcon>
  );
};
